@@ -13,7 +13,6 @@ We can also move the implementation to C++ if desired.
 """
 
 import inspect
-from collections import namedtuple
 from collections.abc import KeysView
 from io import BytesIO
 from subprocess import PIPE, run
@@ -100,7 +99,10 @@ def _mudraw(buffer, fmt):
         tmp_in.flush()
 
         proc = run(
-            ['mudraw', '-F', fmt, '-o', '-', tmp_in.name], stdout=PIPE, stderr=PIPE
+            ['mudraw', '-F', fmt, '-o', '-', tmp_in.name],
+            stdout=PIPE,
+            stderr=PIPE,
+            check=True,
         )
         if proc.stderr:
             raise RuntimeError(proc.stderr.decode())
@@ -155,13 +157,17 @@ class Extend_Object:
             >>> pdf.pages[0].objgen
             (16, 0)  # Same object
         """
+        if not self.same_owner_as(other):
+            raise TypeError("Objects must have the same owner for emplace()")
         del_keys = set(self.keys()) - set(other.keys())
         for k in other.keys():
             self[k] = other[k]  # pylint: disable=unsupported-assignment-operation
         for k in del_keys:
             del self[k]  # pylint: disable=unsupported-delete-operation
 
-    def write(self, data, *, filter=None, decode_parms=None, type_check=True):
+    def write(
+        self, data, *, filter=None, decode_parms=None, type_check=True
+    ):  # pylint: disable=redefined-builtin
         """
         Replace stream object's data with new (possibly compressed) `data`.
 
@@ -599,7 +605,7 @@ class Extend_Page:
     def __repr__(self):
         return repr(self.obj).replace('Dictionary', 'Page')
 
-    def _repr_mimebundle_(self, include, exclude, **kwargs):
+    def _repr_mimebundle_(self, include, exclude, **_kwargs):
         data = {}
         bundle = {'application/pdf', 'image/png'}
         if include:
